@@ -5,3 +5,6 @@ from wagtail.users.apps import WagtailUsersAppConfig
 class WagtailTenantsConfig(AppConfig):
     default_auto_field = "django.db.models.BigAutoField"
     name = "wagtail_tenants"
+
+    def ready(self):
+        import wagtail_tenants.signals  # noqa
