@@ -11,12 +11,21 @@ class Client(TenantMixin):
 
     # default true, schema will be automatically created and synced when it is saved
     auto_create_schema = True
+    auto_drop_schema = True
 
     def save(self, *args, **kwargs):
         with schema_context("public"):
             super(Client, self).save(*args, **kwargs)
 
 
+class ClientBackup(models.Model):
+    client = models.ForeignKey(
+        Client, related_name="client_backups", on_delete=models.CASCADE
+    )
+    created_at = models.DateTimeField(auto_now_add=True)
+    filename = models.CharField(null=True, blank=True, max_length=80)
+
+
 class Domain(DomainMixin):
     def save(self, *args, **kwargs):
         with schema_context("public"):
